pub struct GetScriptInfoCommand {
pub property: String,
}Expand description
Command to get a script info property from the ASS document
Retrieves the value of a specific property from the [Script Info] section.
Returns an error if the property doesn’t exist. value
Fields
property: StringProperty name to retrieve
Implementations