ExtensionState

Enum ExtensionState 

pub enum ExtensionState {
    Uninitialized,
    Initializing,
    Active,
    Paused,
    Error,
    ShuttingDown,
    Shutdown,
}
Extension lifecycle state

Variants



Uninitialized

Extension is uninitialized



Initializing

Extension is being initialized



Active

Extension is active and running



Paused

Extension is paused/suspended



Error

Extension encountered an error



ShuttingDown

Extension is being shut down



Shutdown

Extension has been shut down

Implementations

Source

impl ExtensionState

pub fn is_active(&self) -> bool

Check if the extension is in an active state

pub fn is_usable(&self) -> bool

Check if the extension can be used

pub fn is_error(&self) -> bool

Check if the extension is in an error state