pub struct RegistryIntegration { /* private fields */ }Expand description
Wrapper that connects editor extensions to ass-core’s ExtensionRegistry
Implementations
Sourceimpl RegistryIntegration
impl RegistryIntegration
Sourcepub fn register_builtin_handlers(&mut self) -> Result<()>
pub fn register_builtin_handlers(&mut self) -> Result<()>
Register all built-in tag handlers from ass-core
Sourcepub fn register_builtin_sections(&mut self) -> Result<()>
pub fn register_builtin_sections(&mut self) -> Result<()>
Register built-in section processors from ass-core
Sourcepub fn registry(&self) -> &ExtensionRegistry
pub fn registry(&self) -> &ExtensionRegistry
Get the underlying ExtensionRegistry for use in parsing
Sourcepub fn registry_mut(&mut self) -> &mut ExtensionRegistry
pub fn registry_mut(&mut self) -> &mut ExtensionRegistry
Get mutable access to the registry
Sourcepub fn register_custom_tag_handler(
&mut self,
extension_name: String,
handler: Box<dyn TagHandler>,
) -> Result<()>
pub fn register_custom_tag_handler( &mut self, extension_name: String, handler: Box<dyn TagHandler>, ) -> Result<()>
Register a custom tag handler from an editor extension
Sourcepub fn register_custom_section_processor(
&mut self,
extension_name: String,
processor: Box<dyn SectionProcessor>,
) -> Result<()>
pub fn register_custom_section_processor( &mut self, extension_name: String, processor: Box<dyn SectionProcessor>, ) -> Result<()>
Register a custom section processor from an editor extension