Position and range types for document editing
Provides types and builders for working with positions and ranges in documents. Supports both byte offsets and line/column positions with efficient conversion between them using the rope data structure.
Structs
- Line
Column - A line/column position in a document
- Position
- A position in a document represented as byte offset
- Position
Builder - Builder for creating document positions with fluent API
- Range
- A range in a document represented by start and end positions
- Selection
- Selection represents a range with a direction